You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tapestry.apache.org by hl...@apache.org on 2008/05/20 20:52:29 UTC

svn commit: r658390 [3/32] - in /tapestry/tapestry5/branches/hlship-20080520: ./ quickstart/src/main/resources/META-INF/ quickstart/src/main/resources/archetype-resources/src/main/java/pages/ quickstart/src/main/resources/archetype-resources/src/main/j...

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/RadioContainer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/RadioContainer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/RadioContainer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/RadioContainer.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.corelib.components.Radio;
+import org.apache.tapestry5.corelib.components.Radio;
 
 /**
  * A container of {@link Radio} components, used to identify the element name used when rendering the individual radio

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/RenderSupport.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/RenderSupport.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/RenderSupport.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/RenderSupport.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.services.SymbolSource;
-import org.apache.tapestry.services.AssetSource;
+import org.apache.tapestry5.ioc.services.SymbolSource;
+import org.apache.tapestry5.services.AssetSource;
 import org.apache.tapestry5.json.JSONArray;
 import org.apache.tapestry5.json.JSONObject;
 
@@ -32,7 +32,7 @@
      *
      * @param id the component id from which a unique id will be generated
      * @return a unique id for this rendering of the page
-     * @see org.apache.tapestry.ioc.internal.util.IdAllocator
+     * @see org.apache.tapestry5.ioc.internal.util.IdAllocator
      */
     String allocateClientId(String id);
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Renderable.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Renderable.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SelectModelVisitor.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SelectModelVisitor.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Callback interface that allows for visiting the option groups and option models of a select model in correct render

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/StreamResponse.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/StreamResponse.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/StreamResponse.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/StreamResponse.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.services.Response;
+import org.apache.tapestry5.services.Response;
 
 import java.io.BufferedInputStream;
 import java.io.IOException;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SymbolConstants.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SymbolConstants.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SymbolConstants.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SymbolConstants.java Tue May 20 11:51:35 2008
@@ -1,9 +1,9 @@
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Defines the names of symbols used to configure Tapestry.
  *
- * @see org.apache.tapestry.ioc.services.SymbolSource
+ * @see org.apache.tapestry5.ioc.services.SymbolSource
  */
 public class SymbolConstants
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/TapestryFilter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/TapestryFilter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/TapestryFilter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/TapestryFilter.java Tue May 20 11:51:35 2008
@@ -12,18 +12,18 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.internal.ServletContextSymbolProvider;
-import org.apache.tapestry.internal.TapestryAppInitializer;
-import org.apache.tapestry.ioc.Registry;
-import org.apache.tapestry.ioc.def.ModuleDef;
-import org.apache.tapestry.ioc.services.ServiceActivity;
-import org.apache.tapestry.ioc.services.ServiceActivityScoreboard;
-import org.apache.tapestry.ioc.services.Status;
-import org.apache.tapestry.ioc.services.SymbolProvider;
-import org.apache.tapestry.services.HttpServletRequestHandler;
-import org.apache.tapestry.services.ServletApplicationInitializer;
+import org.apache.tapestry5.internal.ServletContextSymbolProvider;
+import org.apache.tapestry5.internal.TapestryAppInitializer;
+import org.apache.tapestry5.ioc.Registry;
+import org.apache.tapestry5.ioc.def.ModuleDef;
+import org.apache.tapestry5.ioc.services.ServiceActivity;
+import org.apache.tapestry5.ioc.services.ServiceActivityScoreboard;
+import org.apache.tapestry5.ioc.services.Status;
+import org.apache.tapestry5.ioc.services.SymbolProvider;
+import org.apache.tapestry5.services.HttpServletRequestHandler;
+import org.apache.tapestry5.services.ServletApplicationInitializer;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Translator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Translator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Translator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Translator.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.Messages;
-import org.apache.tapestry.services.ValidationMessagesSource;
+import org.apache.tapestry5.ioc.Messages;
+import org.apache.tapestry5.services.ValidationMessagesSource;
 
 /**
  * Translates between client-side and server-side values. Client-side values are always strings.
  *
  * @param <T>
- * @see org.apache.tapestry.services.TranslatorDefaultSource
+ * @see org.apache.tapestry5.services.TranslatorDefaultSource
  * @see FieldValidationSupport
  */
 public interface Translator<T>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationDecorator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationDecorator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationException.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationException.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * An exception associated with parsing client input, or validating the input against a constraint.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationTracker.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationTracker.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationTracker.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationTracker.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.corelib.components.Loop;
+import org.apache.tapestry5.corelib.components.Loop;
 
 import java.util.List;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationTrackerImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationTrackerImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationTrackerImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationTrackerImpl.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
 
 import java.io.Serializable;
 import java.util.List;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Validator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Validator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/VersionUtils.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/VersionUtils.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 import java.io.BufferedInputStream;
 import java.io.IOException;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRender.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRender.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRenderBody.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRenderBody.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRenderTemplate.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRenderTemplate.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRenderTemplate.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRenderTemplate.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ApplicationState.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ApplicationState.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ApplicationState.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ApplicationState.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
-import org.apache.tapestry.services.ApplicationStateManager;
+import org.apache.tapestry5.services.ApplicationStateManager;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeforeRenderBody.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeforeRenderBody.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeforeRenderTemplate.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeforeRenderTemplate.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeginRender.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeginRender.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Cached.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Cached.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.*;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/CleanupRender.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/CleanupRender.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Component.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Component.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ContentType.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ContentType.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ContentType.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ContentType.java Tue May 20 11:51:35 2008
@@ -12,17 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.*;
 
 
 /**
  * An annotation on a page component used to identify the content type the page returns. An alternative to the {@link
- * org.apache.tapestry.annotation.Meta} annotation with the {@link org.apache.tapestry.MetaDataConstants#RESPONSE_CONTENT_TYPE}
+ * org.apache.tapestry5.annotations.Meta} annotation with the {@link org.apache.tapestry5.MetaDataConstants#RESPONSE_CONTENT_TYPE}
  * key.
  *
- * @see org.apache.tapestry.annotation.ResponseEncoding
+ * @see org.apache.tapestry5.annotations.ResponseEncoding
  */
 @Target({ ElementType.TYPE })
 @Retention(RetentionPolicy.RUNTIME)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Environmental.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Environmental.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Environmental.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Environmental.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
-import org.apache.tapestry.services.Environment;
+import org.apache.tapestry5.services.Environment;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Id.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Id.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Id.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Id.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
-import org.apache.tapestry.Block;
-import org.apache.tapestry.ioc.annotation.Inject;
+import org.apache.tapestry5.Block;
+import org.apache.tapestry5.ioc.annotations.Inject;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/IncludeJavaScriptLibrary.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/IncludeJavaScriptLibrary.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/IncludeJavaScriptLibrary.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/IncludeJavaScriptLibrary.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.*;
 
@@ -21,8 +21,8 @@
  * Allows for the inclusion of one or more JavaScript libraries.  The libraries are assets, usually (but not always)
  * stored on the classpath with the component.
  *
- * @see org.apache.tapestry.annotation.IncludeStylesheet
- * @see org.apache.tapestry.annotation.Path
+ * @see org.apache.tapestry5.annotations.IncludeStylesheet
+ * @see org.apache.tapestry5.annotations.Path
  */
 @Target({ ElementType.TYPE })
 @Retention(RetentionPolicy.RUNTIME)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/IncludeStylesheet.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/IncludeStylesheet.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectComponent.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectComponent.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectContainer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectContainer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectContainer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectContainer.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectPage.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectPage.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectPage.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectPage.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -34,4 +34,4 @@
      * lookup by class name (from the field type).
      */
     String value() default "";
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Log.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Log.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Log.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Log.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.*;
 
@@ -21,7 +21,7 @@
  * Marker annotation for component methods to enable debug-level logging. Annotated methods will log method entry (with
  * parameters), method exit (with return value, for non-void methods) and any thrown exceptions.
  *
- * @see org.apache.tapestry.internal.transform.LogWorker
+ * @see org.apache.tapestry5.internal.transform.LogWorker
  */
 @Target(ElementType.METHOD)
 @Retention(RetentionPolicy.RUNTIME)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Meta.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Meta.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Meta.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Meta.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
-import org.apache.tapestry.model.ComponentModel;
+import org.apache.tapestry5.model.ComponentModel;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.TYPE;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Mixin.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Mixin.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Mixin.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Mixin.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/MixinAfter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/MixinAfter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/MixinAfter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/MixinAfter.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.TYPE;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/MixinClasses.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/MixinClasses.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/MixinClasses.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/MixinClasses.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Mixins.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Mixins.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Mixins.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Mixins.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/OnEvent.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/OnEvent.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageAttached.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageAttached.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageDetached.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageDetached.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageDetached.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageDetached.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageLoaded.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageLoaded.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageLoaded.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageLoaded.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Parameter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Parameter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Path.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Path.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
-import org.apache.tapestry.Asset;
-import org.apache.tapestry.ioc.annotation.Inject;
+import org.apache.tapestry5.Asset;
+import org.apache.tapestry5.ioc.annotations.Inject;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Persist.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Persist.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Persist.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Persist.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
-import org.apache.tapestry.services.MetaDataLocator;
-import org.apache.tapestry.services.Session;
+import org.apache.tapestry5.services.MetaDataLocator;
+import org.apache.tapestry5.services.Session;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Property.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Property.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Property.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Property.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ResponseEncoding.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ResponseEncoding.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Retain.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Retain.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Secure.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Secure.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Secure.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Secure.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.TYPE;
@@ -23,7 +23,7 @@
 /**
  * A marker annotation that indicates that the page in question may only be accessed via HTTPS.
  *
- * @see org.apache.tapestry.MetaDataConstants#SECURE_PAGE
+ * @see org.apache.tapestry5.MetaDataConstants#SECURE_PAGE
  */
 @Target(TYPE)
 @Retention(RUNTIME)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Service.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Service.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Service.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Service.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
-import org.apache.tapestry.ioc.annotation.Inject;
+import org.apache.tapestry5.ioc.annotations.Inject;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/SetupRender.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/SetupRender.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/SupportsInformalParameters.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/SupportsInformalParameters.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
-import org.apache.tapestry.model.ComponentModel;
+import org.apache.tapestry5.model.ComponentModel;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.TYPE;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/beaneditor/BeanModel.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/beaneditor/BeanModel.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractField.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractField.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.corelib.base;
+package org.apache.tapestry5.corelib.base;
 
-import org.apache.tapestry.*;
-import org.apache.tapestry.annotation.*;
-import org.apache.tapestry.corelib.mixins.DiscardBody;
-import org.apache.tapestry.corelib.mixins.RenderDisabled;
-import org.apache.tapestry.corelib.mixins.RenderInformals;
-import org.apache.tapestry.ioc.annotation.Inject;
-import org.apache.tapestry.services.ComponentDefaultProvider;
-import org.apache.tapestry.services.FormSupport;
+import org.apache.tapestry5.*;
+import org.apache.tapestry5.annotations.*;
+import org.apache.tapestry5.corelib.mixins.DiscardBody;
+import org.apache.tapestry5.corelib.mixins.RenderDisabled;
+import org.apache.tapestry5.corelib.mixins.RenderInformals;
+import org.apache.tapestry5.ioc.annotations.Inject;
+import org.apache.tapestry5.services.ComponentDefaultProvider;
+import org.apache.tapestry5.services.FormSupport;
 
 import java.io.Serializable;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractLink.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractLink.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Renderable.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Renderable.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Base interface for objects that can render markup output using a {@link org.apache.tapestry.MarkupWriter}.
  */
 public interface Renderable
 {
@@ -12,10 +12,10 @@
 
 /**
- * Base interface for objects that can render markup output using a {@link org.apache.tapestry.MarkupWriter}.
+ * Base interface for objects that can render markup output using a {@link org.apache.tapestry5.MarkupWriter}.
  */
 public interface Renderable

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SelectModel.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SelectModel.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SelectModel.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SelectModel.java Tue May 20 11:51:35 2008
@@ -12,18 +12,18 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 import java.util.List;
 
 /**
  * Defines the possible options and option groups for a <select> [X]HTML element.
  * <p/>
  * Primarily used by the {@link org.apache.tapestry.corelib.components.Select} component, but potentially used by
  * anything similar, that needs to present a list of options to the user. Generally paired with a {@link
  * org.apache.tapestry.ValueEncoder} to create client-side representations of server-side values.
  *
- * @see org.apache.tapestry.corelib.components.Palette
+ * @see org.apache.tapestry5.corelib.components.Palette
  */
 public interface SelectModel
 {
@@ -12,18 +12,18 @@
  * Defines the possible options and option groups for a <select> [X]HTML element.
  * <p/>
- * Primarily used by the {@link org.apache.tapestry.corelib.components.Select} component, but potentially used by
+ * Primarily used by the {@link org.apache.tapestry5.corelib.components.Select} component, but potentially used by
  * anything similar, that needs to present a list of options to the user. Generally paired with a {@link
@@ -12,18 +12,18 @@
  * anything similar, that needs to present a list of options to the user. Generally paired with a {@link
- * org.apache.tapestry.ValueEncoder} to create client-side representations of server-side values.
+ * org.apache.tapestry5.ValueEncoder} to create client-side representations of server-side values.
  *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SelectModelVisitor.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/SelectModelVisitor.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationDecorator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationDecorator.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.dom.Element;
+import org.apache.tapestry5.dom.Element;
 
 /**
  * An object responsible for performing decorations around fields and field labels. The decorator is notified at
@@ -22,13 +22,13 @@
  * <p/>
  * In most western languages (written left to right) the label will render before the field, so the properties of the
  * Field may not be set yet (or may reflect a previous looping's rendering). It may be necessary to {@linkplain
  * org.apache.tapestry.services.Heartbeat#defer(Runnable)} defer any rendering} until after the Label and the Field have
  * both had their change to initialize and render.
  */
 public interface ValidationDecorator
 {
     /**
      * Invoked by a {@link org.apache.tapestry.corelib.components.Label} before rendering itself.
      *
      * @param field for this label
      */
@@ -45,7 +45,7 @@
 
 
     /**
      * Invoked by {@link org.apache.tapestry.corelib.components.Label} after rendering itself.
      *
      * @param field
      */
@@ -22,13 +22,13 @@
  * In most western languages (written left to right) the label will render before the field, so the properties of the
  * Field may not be set yet (or may reflect a previous looping's rendering). It may be necessary to {@linkplain
- * org.apache.tapestry.services.Heartbeat#defer(Runnable)} defer any rendering} until after the Label and the Field have
+ * org.apache.tapestry5.services.Heartbeat#defer(Runnable)} defer any rendering} until after the Label and the Field have
  * both had their change to initialize and render.
  */
@@ -22,13 +22,13 @@
 {
     /**
-     * Invoked by a {@link org.apache.tapestry.corelib.components.Label} before rendering itself.
+     * Invoked by a {@link org.apache.tapestry5.corelib.components.Label} before rendering itself.
      *
      * @param field for this label
@@ -45,7 +45,7 @@
 
     /**
-     * Invoked by {@link org.apache.tapestry.corelib.components.Label} after rendering itself.
+     * Invoked by {@link org.apache.tapestry5.corelib.components.Label} after rendering itself.
      *
      * @param field

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationException.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValidationException.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Validator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Validator.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.MessageFormatter;
-import org.apache.tapestry.services.FormSupport;
-import org.apache.tapestry.services.ValidationMessagesSource;
+import org.apache.tapestry5.ioc.MessageFormatter;
+import org.apache.tapestry5.services.FormSupport;
+import org.apache.tapestry5.services.ValidationMessagesSource;
 
 /**
  * Used by a {@link Field} to enforce a <strong>constraint</strong> related to a form submission. Validators themselves
@@ -25,7 +25,7 @@
  * Validators are usually encapsulated inside a {@link FieldValidator}.
  *
  * @see FieldValidationSupport
- * @see org.apache.tapestry.services.FieldValidatorDefaultSource
+ * @see org.apache.tapestry5.services.FieldValidatorDefaultSource
  */
 public interface Validator<C, T>
 {
@@ -53,7 +53,7 @@
     String getMessageKey();
 
     /**
      * Invoked after the client-submitted value has been {@link org.apache.tapestry.Translator translated} to check that
      * the value conforms to expectations (often, in terms of minimum or maximum value). If and only if the value is
      * approved by all Validators is the value applied by the field.
      *
@@ -68,7 +68,7 @@
     /**
      * Returns true if the validator should be invoked for null or blank (empty string) values. This is generally false,
      * but is true for validators that enforce that a non-blank value is required.  This is the basis of the {@link
-     * org.apache.tapestry.Field#isRequired()} property.
+     * org.apache.tapestry5.Field#isRequired()} property.
      */
     boolean isRequired();
 
@@ -53,7 +53,7 @@
 
     /**
-     * Invoked after the client-submitted value has been {@link org.apache.tapestry.Translator translated} to check that
+     * Invoked after the client-submitted value has been {@link org.apache.tapestry5.Translator translated} to check that
      * the value conforms to expectations (often, in terms of minimum or maximum value). If and only if the value is
      * approved by all Validators is the value applied by the field.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValueEncoder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValueEncoder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValueEncoder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ValueEncoder.java Tue May 20 11:51:35 2008
@@ -12,18 +12,18 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Used to convert server side values to client-side strings.  This is used when generating a {@link
  * org.apache.tapestry.EventContext} as part of a URL, or when components (such as {@link
  * org.apache.tapestry.corelib.components.Select}) generated other client-side strings.
  * <p/>
  * Often a custom implementation is needed for entity type objects, where the {@link #toClient(Object)} method extracts
  * a primary key, and the {@link #toValue(String)} re-acquires the corresponding entity object.
  *
  * @see SelectModel
- * @see org.apache.tapestry.services.ValueEncoderSource
+ * @see org.apache.tapestry5.services.ValueEncoderSource
  * @see PrimaryKeyEncoder
  */
 public interface ValueEncoder<V>
@@ -12,18 +12,18 @@
 /**
  * Used to convert server side values to client-side strings.  This is used when generating a {@link
- * org.apache.tapestry.EventContext} as part of a URL, or when components (such as {@link
- * org.apache.tapestry.corelib.components.Select}) generated other client-side strings.
+ * org.apache.tapestry5.EventContext} as part of a URL, or when components (such as {@link
+ * org.apache.tapestry5.corelib.components.Select}) generated other client-side strings.
  * <p/>
  * Often a custom implementation is needed for entity type objects, where the {@link #toClient(Object)} method extracts

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/VersionUtils.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/VersionUtils.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRender.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRender.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;
@@ -22,10 +22,10 @@
 
 /**
  * Marker annotation for methods associated with the AfterRender phase. This corresponds closely to {@link
  * org.apache.tapestry.annotation.BeginRender}, but occurs after the template and body of the component have been
  * rendered. Often, this is used to render a close tag. Return void or true (the default) to advance to the {@link
  * org.apache.tapestry.annotation.CleanupRender} phase. Return false to return to the {@link
  * org.apache.tapestry.annotation.BeginRender} phase.
  */
 @Target(ElementType.METHOD)
 @Retention(RUNTIME)
@@ -22,10 +22,10 @@
 /**
  * Marker annotation for methods associated with the AfterRender phase. This corresponds closely to {@link
- * org.apache.tapestry.annotation.BeginRender}, but occurs after the template and body of the component have been
+ * org.apache.tapestry5.annotations.BeginRender}, but occurs after the template and body of the component have been
  * rendered. Often, this is used to render a close tag. Return void or true (the default) to advance to the {@link
@@ -22,10 +22,10 @@
  * rendered. Often, this is used to render a close tag. Return void or true (the default) to advance to the {@link
- * org.apache.tapestry.annotation.CleanupRender} phase. Return false to return to the {@link
- * org.apache.tapestry.annotation.BeginRender} phase.
+ * org.apache.tapestry5.annotations.CleanupRender} phase. Return false to return to the {@link
+ * org.apache.tapestry5.annotations.BeginRender} phase.
  */
 @Target(ElementType.METHOD)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRenderBody.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/AfterRenderBody.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeforeRenderBody.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeforeRenderBody.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;
@@ -22,13 +22,13 @@
 
 /**
  * Marks methods to be invoked when the component rendering state machine hits the point in the component's template
- * where the body element occurs. Such methods may optionally take a {@link org.apache.tapestry.MarkupWriter} parameter,
- * and may return void or boolean.
+ * where the body element occurs. Such methods may optionally take a {@link org.apache.tapestry5.MarkupWriter}
+ * parameter, and may return void or boolean.
  * <p/>
  * Returning true (or void) will queue up the component's body for rendering.
  * <p/>
  * Returning false will skip the component's body, but continue rendering the template. The {@link
  * org.apache.tapestry.annotation.AfterRenderBody} phase will still execute after the template finishes rendering.
  * <p/>
  * This phase is skipped for components which do not have a body.
  */
@@ -22,13 +22,13 @@
  * <p/>
  * Returning false will skip the component's body, but continue rendering the template. The {@link
- * org.apache.tapestry.annotation.AfterRenderBody} phase will still execute after the template finishes rendering.
+ * org.apache.tapestry5.annotations.AfterRenderBody} phase will still execute after the template finishes rendering.
  * <p/>
  * This phase is skipped for components which do not have a body.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeforeRenderTemplate.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeforeRenderTemplate.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeginRender.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/BeginRender.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;
@@ -24,15 +24,15 @@
  * Marker annotation for methods that should be executed at the start of rendering the component. This usually includes
  * rendering of the component's start tag.
  * <p/>
  * Such methods may optionally take a {@link org.apache.tapestry.MarkupWriter} parameter, and may return void or
  * boolean. Returning true or void will allow the component to advance into the render template / render body phase. If
  * a body is present, the {@link org.apache.tapestry.annotation.BeforeRenderBody} phase will execute. If a component has
  * a template, the {@link BeforeRenderTemplate} phase will execute (and the render body will only occur if the template
  * directs so).
  * <p/>
  * Either way, the {@link org.apache.tapestry.annotation.AfterRender} phase will execute after the template and/or body
  * have rendered. A component with a body but without a template will still see the {@link
  * org.apache.tapestry.annotation.BeforeRenderBody} phase execute.
  * <p/>
  * Returning false will skip rendering of the template and/or body, and jump directly to the {@link AfterRender} phase.
  */
@@ -24,15 +24,15 @@
  * rendering of the component's start tag.
  * <p/>
- * Such methods may optionally take a {@link org.apache.tapestry.MarkupWriter} parameter, and may return void or
+ * Such methods may optionally take a {@link org.apache.tapestry5.MarkupWriter} parameter, and may return void or
  * boolean. Returning true or void will allow the component to advance into the render template / render body phase. If
@@ -24,15 +24,15 @@
  * boolean. Returning true or void will allow the component to advance into the render template / render body phase. If
- * a body is present, the {@link org.apache.tapestry.annotation.BeforeRenderBody} phase will execute. If a component has
- * a template, the {@link BeforeRenderTemplate} phase will execute (and the render body will only occur if the template
- * directs so).
+ * a body is present, the {@link org.apache.tapestry5.annotations.BeforeRenderBody} phase will execute. If a component
+ * has a template, the {@link BeforeRenderTemplate} phase will execute (and the render body will only occur if the
+ * template directs so).
  * <p/>
@@ -24,15 +24,15 @@
  * <p/>
- * Either way, the {@link org.apache.tapestry.annotation.AfterRender} phase will execute after the template and/or body
- * have rendered. A component with a body but without a template will still see the {@link
- * org.apache.tapestry.annotation.BeforeRenderBody} phase execute.
+ * Either way, the {@link org.apache.tapestry5.annotations.AfterRender} phase will execute after the template and/or
+ * body have rendered. A component with a body but without a template will still see the {@link
+ * org.apache.tapestry5.annotations.BeforeRenderBody} phase execute.
  * <p/>
  * Returning false will skip rendering of the template and/or body, and jump directly to the {@link AfterRender} phase.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Cached.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Cached.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/CleanupRender.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/CleanupRender.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;
@@ -22,9 +22,9 @@
 
 /**
  * Marker annotation for component methods associated with the terminal phase for the component rendering state machine.
  * Methods may optionally take a {@link org.apache.tapestry.MarkupWriter} annotation. Generally, methods marked with
  * this annotation are used to perform post-render cleanup. In addition, a method may return false to return to the
  * {@link org.apache.tapestry.annotation.SetupRender} phase. Returning void or true (the default), is the normal
  * course.
  */
 @Target(ElementType.METHOD)
@@ -22,9 +22,9 @@
 /**
  * Marker annotation for component methods associated with the terminal phase for the component rendering state machine.
- * Methods may optionally take a {@link org.apache.tapestry.MarkupWriter} annotation. Generally, methods marked with
+ * Methods may optionally take a {@link org.apache.tapestry5.MarkupWriter} annotation. Generally, methods marked with
  * this annotation are used to perform post-render cleanup. In addition, a method may return false to return to the
@@ -22,9 +22,9 @@
  * this annotation are used to perform post-render cleanup. In addition, a method may return false to return to the
- * {@link org.apache.tapestry.annotation.SetupRender} phase. Returning void or true (the default), is the normal
+ * {@link org.apache.tapestry5.annotations.SetupRender} phase. Returning void or true (the default), is the normal
  * course.
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Component.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Component.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/IncludeStylesheet.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/IncludeStylesheet.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.*;
 
@@ -25,11 +25,11 @@
  * This saves the work of injecting the asset into a field and injecting the PageRenderSupport environmental service,
  * and invoking the method.
  * <p/>
  * Does not support setting a media type; if that is required. use {@link org.apache.tapestry.RenderSupport#addStylesheetLink(org.apache.tapestry.Asset,
  * String)} directly.
  *
- * @see org.apache.tapestry.annotation.Path
- * @see org.apache.tapestry.annotation.IncludeJavaScriptLibrary
+ * @see org.apache.tapestry5.annotations.Path
+ * @see org.apache.tapestry5.annotations.IncludeJavaScriptLibrary
  */
 @Target({ ElementType.TYPE })
 @Retention(RetentionPolicy.RUNTIME)
@@ -25,11 +25,11 @@
  * and invoking the method.
  * <p/>
- * Does not support setting a media type; if that is required. use {@link org.apache.tapestry.RenderSupport#addStylesheetLink(org.apache.tapestry.Asset,
+ * Does not support setting a media type; if that is required. use {@link org.apache.tapestry5.RenderSupport#addStylesheetLink(org.apache.tapestry5.Asset,
  * String)} directly.
  *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectComponent.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/InjectComponent.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/OnEvent.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/OnEvent.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
-import org.apache.tapestry.EventConstants;
+import org.apache.tapestry5.EventConstants;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;
@@ -29,7 +29,7 @@
  * <p/>
  * Client events include a <em>context</em> of one or more values. These context values are included in the action URI.
  * The values are optionally supplied to the handler method as parameters. Automatic {@linkplain
  * org.apache.tapestry.ValueEncoder conversion} from string to the type of the actual parameter occur.
  * <p/>
  * Handlers may return a value. Returning a non-null value will abort the handling of the event, and will usually
  * control the response sent to the client web browser. The details are somewhat specific to the type of event and the
@@ -53,7 +53,7 @@
      * The event type to match. The handler will only be invoked if the client event type matches the value. The default
      * value is "action".  Matching is case-insensitive.
      *
-     * @see org.apache.tapestry.EventConstants
+     * @see org.apache.tapestry5.EventConstants
      */
     String value() default EventConstants.ACTION;
 
@@ -29,7 +29,7 @@
  * Client events include a <em>context</em> of one or more values. These context values are included in the action URI.
  * The values are optionally supplied to the handler method as parameters. Automatic {@linkplain
- * org.apache.tapestry.ValueEncoder conversion} from string to the type of the actual parameter occur.
+ * org.apache.tapestry5.ValueEncoder conversion} from string to the type of the actual parameter occur.
  * <p/>
  * Handlers may return a value. Returning a non-null value will abort the handling of the event, and will usually

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageAttached.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/PageAttached.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Parameter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Parameter.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
-import org.apache.tapestry.BindingConstants;
-import org.apache.tapestry.services.BindingFactory;
+import org.apache.tapestry5.BindingConstants;
+import org.apache.tapestry5.services.BindingFactory;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -48,7 +48,7 @@
     /**
      * If true (the default), then the value for the parameter is cached while the component is, itself, rendering.
      * Values from invariant bindings (such as literal strings) are always cached, regardless of this setting. Set this
      * attribute to false to force the parameter to be {@link org.apache.tapestry.Binding#get() re-read} every time the
      * field is accessed, even while the component is rendering.
      */
     boolean cache() default true;
@@ -65,7 +65,7 @@
      * specific {@link BindingFactory} implementations, and used with parameters whose name reflects the binding
      * prefix.
      *
-     * @see org.apache.tapestry.BindingConstants
+     * @see org.apache.tapestry5.BindingConstants
      */
     String defaultPrefix() default BindingConstants.PROP;
 
@@ -48,7 +48,7 @@
      * If true (the default), then the value for the parameter is cached while the component is, itself, rendering.
      * Values from invariant bindings (such as literal strings) are always cached, regardless of this setting. Set this
-     * attribute to false to force the parameter to be {@link org.apache.tapestry.Binding#get() re-read} every time the
+     * attribute to false to force the parameter to be {@link org.apache.tapestry5.Binding#get() re-read} every time the
      * field is accessed, even while the component is rendering.
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Path.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Path.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ResponseEncoding.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/ResponseEncoding.java Tue May 20 11:51:35 2008
@@ -12,17 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.*;
 
 
 /**
  * An annotation on a page component used to identify the respones encoding (the character set of the text sent in the
  * response). An alternative to the {@link org.apache.tapestry.annotation.Meta} annotation with the {@link
  * org.apache.tapestry.MetaDataConstants#RESPONSE_ENCODING} key.
  *
- * @see org.apache.tapestry.annotation.ContentType
+ * @see org.apache.tapestry5.annotations.ContentType
  */
 @Target({ ElementType.TYPE })
 @Retention(RetentionPolicy.RUNTIME)
@@ -12,17 +12,17 @@
 /**
  * An annotation on a page component used to identify the respones encoding (the character set of the text sent in the
- * response). An alternative to the {@link org.apache.tapestry.annotation.Meta} annotation with the {@link
- * org.apache.tapestry.MetaDataConstants#RESPONSE_ENCODING} key.
+ * response). An alternative to the {@link org.apache.tapestry5.annotations.Meta} annotation with the {@link
+ * org.apache.tapestry5.MetaDataConstants#RESPONSE_ENCODING} key.
  *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Retain.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/Retain.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/SetupRender.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/SetupRender.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.annotation;
+package org.apache.tapestry5.annotations;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;
@@ -22,9 +22,9 @@
 
 /**
  * Marker annotation for methods that should be executed during the SetupRender phase. Such methods may optionally take
  * a {@link org.apache.tapestry.MarkupWriter} parameter, and may return void or boolean. Returning true or void will
  * advance to the {@link org.apache.tapestry.annotation.BeginRender} phase. Return false to skip the BeginRender phase
  * and procede directly to the {@link org.apache.tapestry.annotation.CleanupRender} phase.
  */
 @Target(ElementType.METHOD)
 @Retention(RUNTIME)
@@ -22,9 +22,9 @@
 /**
  * Marker annotation for methods that should be executed during the SetupRender phase. Such methods may optionally take
- * a {@link org.apache.tapestry.MarkupWriter} parameter, and may return void or boolean. Returning true or void will
- * advance to the {@link org.apache.tapestry.annotation.BeginRender} phase. Return false to skip the BeginRender phase
- * and procede directly to the {@link org.apache.tapestry.annotation.CleanupRender} phase.
+ * a {@link org.apache.tapestry5.MarkupWriter} parameter, and may return void or boolean. Returning true or void will
+ * advance to the {@link org.apache.tapestry5.annotations.BeginRender} phase. Return false to skip the BeginRender phase
+ * and procede directly to the {@link org.apache.tapestry5.annotations.CleanupRender} phase.
  */
 @Target(ElementType.METHOD)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/SupportsInformalParameters.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/annotations/SupportsInformalParameters.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/beaneditor/BeanModel.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/beaneditor/BeanModel.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.beaneditor;
+package org.apache.tapestry5.beaneditor;
 
-import org.apache.tapestry.PropertyConduit;
+import org.apache.tapestry5.PropertyConduit;
 
 import java.util.List;
 
@@ -24,11 +24,11 @@
  * <p/>
  * BeanModels are not thread-safe, they are also not serializable.
  * <p/>
  * Here, and in {@link org.apache.tapestry.beaneditor.PropertyModel}, the term "propertyName" is used for simplicitly.
  * However, a full {@linkplain org.apache.tapestry.services.PropertyConduitSource#create(Class, String) property
  * expression} may be utilized when {@linkplain #add(String) adding new properties to an existing BeanModel}.
  *
- * @see org.apache.tapestry.services.BeanModelSource
+ * @see org.apache.tapestry5.services.BeanModelSource
  */
 public interface BeanModel<T>
 {
@@ -39,8 +39,8 @@
 
 
     /**
      * Creates a new bean instance.  This is based on {@link org.apache.tapestry.ioc.ObjectLocator#autobuild(Class)}, so
      * a public constructor will be used, and dependencies injected.
      *
      * @return new instance of the bean
      */
@@ -63,7 +63,7 @@
     /**
      * Returns the identified model.  Property ids are a stripped version of the property name. Case is ignored.
      *
-     * @param propertyId matched caselessly against {@link org.apache.tapestry.beaneditor.PropertyModel#getId()}
+     * @param propertyId matched caselessly against {@link org.apache.tapestry5.beaneditor.PropertyModel#getId()}
      * @throws RuntimeException if the bean editor model does not have a property model with the indicated id
      */
     PropertyModel getById(String propertyId);
@@ -24,11 +24,11 @@
  * BeanModels are not thread-safe, they are also not serializable.
  * <p/>
- * Here, and in {@link org.apache.tapestry.beaneditor.PropertyModel}, the term "propertyName" is used for simplicitly.
- * However, a full {@linkplain org.apache.tapestry.services.PropertyConduitSource#create(Class, String) property
+ * Here, and in {@link org.apache.tapestry5.beaneditor.PropertyModel}, the term "propertyName" is used for simplicitly.
+ * However, a full {@linkplain org.apache.tapestry5.services.PropertyConduitSource#create(Class, String) property
  * expression} may be utilized when {@linkplain #add(String) adding new properties to an existing BeanModel}.
  *
@@ -39,8 +39,8 @@
 
     /**
-     * Creates a new bean instance.  This is based on {@link org.apache.tapestry.ioc.ObjectLocator#autobuild(Class)}, so
-     * a public constructor will be used, and dependencies injected.
+     * Creates a new bean instance.  This is based on {@link org.apache.tapestry5.ioc.ObjectLocator#autobuild(Class)},
+     * so a public constructor will be used, and dependencies injected.
      *
      * @return new instance of the bean

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/beaneditor/PropertyModel.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/beaneditor/PropertyModel.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/beaneditor/PropertyModel.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/beaneditor/PropertyModel.java Tue May 20 11:51:35 2008
@@ -12,18 +12,18 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.beaneditor;
+package org.apache.tapestry5.beaneditor;
 
-import org.apache.tapestry.PropertyConduit;
-import org.apache.tapestry.ioc.AnnotationProvider;
+import org.apache.tapestry5.PropertyConduit;
+import org.apache.tapestry5.ioc.AnnotationProvider;
 
 /**
  * Part of a {@link org.apache.tapestry.beaneditor.BeanModel} that defines the attributes of a single property of a
  * bean.
  * <p/>
  * <p/>
  * A PropertyModel is also an {@link AnnotationProvider}, as long as the {@link org.apache.tapestry.PropertyConduit} is
  * non-null.  When there is no property conduit, then {@link org.apache.tapestry.ioc.AnnotationProvider#getAnnotation(Class)}
  * will return null.
  */
 public interface PropertyModel extends AnnotationProvider
@@ -12,18 +12,18 @@
 
 /**
- * Part of a {@link org.apache.tapestry.beaneditor.BeanModel} that defines the attributes of a single property of a
+ * Part of a {@link org.apache.tapestry5.beaneditor.BeanModel} that defines the attributes of a single property of a
  * bean.
  * <p/>
@@ -12,18 +12,18 @@
  * <p/>
  * <p/>
- * A PropertyModel is also an {@link AnnotationProvider}, as long as the {@link org.apache.tapestry.PropertyConduit} is
- * non-null.  When there is no property conduit, then {@link org.apache.tapestry.ioc.AnnotationProvider#getAnnotation(Class)}
+ * A PropertyModel is also an {@link AnnotationProvider}, as long as the {@link org.apache.tapestry5.PropertyConduit} is
+ * non-null.  When there is no property conduit, then {@link org.apache.tapestry5.ioc.AnnotationProvider#getAnnotation(Class)}
  * will return null.
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractComponentEventLink.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractComponentEventLink.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractComponentEventLink.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractComponentEventLink.java Tue May 20 11:51:35 2008
@@ -12,20 +12,20 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.corelib.base;
+package org.apache.tapestry5.corelib.base;
 
-import org.apache.tapestry.BindingConstants;
-import org.apache.tapestry.Link;
-import org.apache.tapestry.MarkupWriter;
-import org.apache.tapestry.annotation.Environmental;
-import org.apache.tapestry.annotation.Parameter;
-import org.apache.tapestry.internal.services.ClientBehaviorSupport;
+import org.apache.tapestry5.BindingConstants;
+import org.apache.tapestry5.Link;
+import org.apache.tapestry5.MarkupWriter;
+import org.apache.tapestry5.annotations.Environmental;
+import org.apache.tapestry5.annotations.Parameter;
+import org.apache.tapestry5.internal.services.ClientBehaviorSupport;
 
 import java.util.List;
 
 /**
  * Base class for link-generating components that are based on a component event request. Such events have an event
  * context and may also update a {@link org.apache.tapestry.corelib.components.Zone}.
  */
 public abstract class AbstractComponentEventLink extends AbstractLink
 {
@@ -12,20 +12,20 @@
 /**
  * Base class for link-generating components that are based on a component event request. Such events have an event
- * context and may also update a {@link org.apache.tapestry.corelib.components.Zone}.
+ * context and may also update a {@link org.apache.tapestry5.corelib.components.Zone}.
  */
 public abstract class AbstractComponentEventLink extends AbstractLink

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractField.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractField.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractLink.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractLink.java Tue May 20 11:51:35 2008
@@ -12,15 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.corelib.base;
+package org.apache.tapestry5.corelib.base;
 
-import org.apache.tapestry.*;
-import org.apache.tapestry.annotation.Parameter;
-import org.apache.tapestry.annotation.SetupRender;
-import org.apache.tapestry.annotation.SupportsInformalParameters;
-import org.apache.tapestry.dom.Element;
-import org.apache.tapestry.internal.services.ComponentInvocationMap;
-import org.apache.tapestry.ioc.annotation.Inject;
+import org.apache.tapestry5.*;
+import org.apache.tapestry5.annotations.Parameter;
+import org.apache.tapestry5.annotations.SetupRender;
+import org.apache.tapestry5.annotations.SupportsInformalParameters;
+import org.apache.tapestry5.dom.Element;
+import org.apache.tapestry5.internal.services.ComponentInvocationMap;
+import org.apache.tapestry5.ioc.annotations.Inject;
 
 /**
  * Provides base utilities for classes that generate clickable links.
@@ -75,7 +75,7 @@
 
     /**
      * Writes an &lt;a&gt; element with the provided link as the href attribute.  A call to {@link
      * org.apache.tapestry.MarkupWriter#end()} is <em>not</em> provided.            Automatically appends an anchor if
      * the component's anchor parameter is non-null.  Informal parameters are rendered as well.
      *
      * @param writer         to write markup to
@@ -96,7 +96,7 @@
     }
 
     /**
      * Returns the most recently rendered {@link org.apache.tapestry.Link} for this component.  Subclasses calculate
      * their link value as they render, and the value is valid until the end of the request, or the next time the same
      * component renders itself (if inside a loop).
      *
@@ -75,7 +75,7 @@
     /**
      * Writes an &lt;a&gt; element with the provided link as the href attribute.  A call to {@link
-     * org.apache.tapestry.MarkupWriter#end()} is <em>not</em> provided.            Automatically appends an anchor if
+     * org.apache.tapestry5.MarkupWriter#end()} is <em>not</em> provided.            Automatically appends an anchor if
      * the component's anchor parameter is non-null.  Informal parameters are rendered as well.
      *
@@ -96,7 +96,7 @@
 
     /**
-     * Returns the most recently rendered {@link org.apache.tapestry.Link} for this component.  Subclasses calculate
+     * Returns the most recently rendered {@link org.apache.tapestry5.Link} for this component.  Subclasses calculate
      * their link value as they render, and the value is valid until the end of the request, or the next time the same
      * component renders itself (if inside a loop).

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractPropertyOutput.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractPropertyOutput.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractPropertyOutput.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/corelib/base/AbstractPropertyOutput.java Tue May 20 11:51:35 2008
@@ -12,19 +12,19 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.corelib.base;
+package org.apache.tapestry5.corelib.base;
 
-import org.apache.tapestry.Block;
-import org.apache.tapestry.ComponentResources;
-import org.apache.tapestry.MarkupWriter;
-import org.apache.tapestry.PropertyConduit;
-import org.apache.tapestry.annotation.Parameter;
-import org.apache.tapestry.beaneditor.PropertyModel;
-import org.apache.tapestry.ioc.Messages;
-import org.apache.tapestry.ioc.annotation.Inject;
-import org.apache.tapestry.services.BeanBlockSource;
-import org.apache.tapestry.services.Environment;
-import org.apache.tapestry.services.PropertyOutputContext;
+import org.apache.tapestry5.Block;
+import org.apache.tapestry5.ComponentResources;
+import org.apache.tapestry5.MarkupWriter;
+import org.apache.tapestry5.PropertyConduit;
+import org.apache.tapestry5.annotations.Parameter;
+import org.apache.tapestry5.beaneditor.PropertyModel;
+import org.apache.tapestry5.ioc.Messages;
+import org.apache.tapestry5.ioc.annotations.Inject;
+import org.apache.tapestry5.services.BeanBlockSource;
+import org.apache.tapestry5.services.Environment;
+import org.apache.tapestry5.services.PropertyOutputContext;
 
 /**
  * Base class for components that output a property value using a {@link PropertyModel}. There's a relationship between
@@ -54,7 +54,7 @@
 
     /**
      * Identifies the object being rendered. The component will extract a property from the object and render its value
      * (or delegate to a {@link org.apache.tapestry.Block} that will do so).
      */
     @Parameter(required = true)
     private Object object;
@@ -54,7 +54,7 @@
     /**
      * Identifies the object being rendered. The component will extract a property from the object and render its value
-     * (or delegate to a {@link org.apache.tapestry.Block} that will do so).
+     * (or delegate to a {@link org.apache.tapestry5.Block} that will do so).
      */
     @Parameter(required = true)